Struct rkyv::collections::btree_set::ArchivedBTreeSet [−][src]
#[repr(transparent)]pub struct ArchivedBTreeSet<K>(_);Expand description
An archived BTreeSet. This is a wrapper around a B-tree map with the same key and a value of
().
Implementations
Returns true if the set contains a value for the specified key.
The key may be any borrowed form of the set’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Returns a reference to the value int he set, if any, that is equal to the given value.
The value may be any borrowed form of the set’s value type, but the ordering on the borrowed form must match the ordering on the value type.
Gets an iterator over the keys of the set, in sorted order.
pub unsafe fn resolve_from_len(
len: usize,
pos: usize,
resolver: BTreeSetResolver,
out: *mut Self
)
pub unsafe fn resolve_from_len(
len: usize,
pos: usize,
resolver: BTreeSetResolver,
out: *mut Self
)
Resolves a B-tree set from its length.
Safety
lenmust be the number of elements that were serializedposmust be the position ofoutwithin the archiveresolvermust be the result of serializing a B-tree set